<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        width="750px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <template #header>
        <div style="text-align: center; width: 100%;font-size: 18px;font-weight: 600">
          <span>{{title}}仓库</span>
        </div>
      </template>
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="117px" >
        <el-form-item>
          <div style="font-size: 16px;font-weight: 600;margin-top: -25px;margin-left: -110px;margin-bottom: -15px">仓库基本信息</div>
        </el-form-item>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="仓库名称:" prop="storeName" >
              <el-input v-model="state.form.storeName" placeholder="请输入仓库名称"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="仓库面积:" prop="acreage" >
              <el-input v-model="state.form.acreage" type="number" min="0" placeholder="请输入仓库面积">
                <template #append>㎡</template>
              </el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="仓库编号:" prop="storeNum" >
              <el-input v-model="state.form.storeNum" placeholder="请输入仓库编号"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="核定药量:" prop="dosage" >
              <el-input v-model="state.form.dosage" type="number" min="0" placeholder="请输入核定药量">
                <template #append>kg</template>
              </el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="危险等级:" prop="dangerLevel" >
              <el-select
                  v-model="state.form.dangerLevel"
                  placeholder="请选择"
                  style="width: 100%"
              >
                <el-option
                    v-for="item in state.typeList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="核定人员数量:" prop="personLimit" >
              <el-input v-model="state.form.personLimit" placeholder="请输入核定人员数量" @input="state.form.personLimit= state.form.personLimit.replace(/[^\d]/g,'')"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {listDept} from "@/api/system/dept";
import {listUser} from "@/api/system/user";
import {addTemplate, editTemplate} from "@/api/signAgreement/template";
import {addType, editType, getSignType} from "@/api/signAgreement/signType";
import {getInfo} from "@/api/login";
import {getToken} from "@/utils/auth";
import {verifyPhone} from "@/utils/validate";
import Cookies from "js-cookie";
import {addWarehouse} from "@/api/company/warehouse";

const uploadFileUrl = ref(import.meta.env.VITE_APP_BASE_API + "/common/upload"); // 上传文件服务器地址
const { proxy } = getCurrentInstance();
const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const startPhone = ref('');
const state = reactive({
  form: {
    id: '',
    acreage: '',
    dangerLevel:null,
    companyCode: '',
    storeNum: '',
    storeName: '',
    personLimit: null,
    dosage: null
  },
  typeList: [
    {
      id: 1,
      name: '1.1级库房'
    },
    {
      id: 2,
      name: '1.3级库房'
    },
    {
      id: 3,
      name: '无药库房'
    },
  ],
  storeroomList: [],
  formRules:{
    acreage: [{ required: true, trigger: "blur", message:'请输入面积' }],
    dangerLevel: [{ required: true, trigger: "blur",message:'请选择危险等级' }],
    dosage: [{ required: true, trigger: "blur", message:'请输入核定药量' }],
    personLimit: [{ required: true, trigger: "blur", message:'请输入核定人员数量' }],
    storeName: [{ required: true, trigger: "blur", message:'请输入仓库名称' }],
    storeNum: [{ required: true, trigger: "blur", message:'请输入仓库编号' }],
  },
})


const openDialog = async (type,value) => {
  title.value = type === 'add' ? '新增' : '编辑'
  const info = JSON.parse(Cookies.get('userInfo'))
  state.form.companyCode = info.companynumber
  if(type === 'edit') {
    const data = JSON.parse(JSON.stringify(value))
    Object.keys(state.form).forEach(key => {
      if(data[key]){
        state.form[key] = data[key]
      }
    })
    state.form.dangerLevel = Number(state.form.dangerLevel)
  }
  dialogVisible.value = true;
}

const onSubmit = async () => {
  console.log('form',state.form)
  const valid = await busRef.value.validate();

  if(valid){
    if(title.value === '新增'){
      const {id,fileList, ...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addWarehouse(data)
      if(res.code == 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addWarehouse(data)
      if(res.code == 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }

  }
}

const addRoom = () => {
  state.storeroomList.push({})
}

const delRoom = (val) => {
  console.log('val',val)
  if(Object.keys(val).length === 0){
    const index = state.storeroomList.findIndex(item => Object.keys(item).length === 0)
    if(index != -1){
      state.storeroomList.splice(index,1)
    }
  }else {
    const index = state.storeroomList.findIndex(item => item == val)
    if(index != -1){
      state.storeroomList.splice(index,1)
    }
  }

}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")
}
const reset = () => {
  state.form = {
    id: '',
    acreage: '',
    dangerLevel:null,
    companyCode: '',
    storeNum: '',
    storeName: '',
    personLimit: null,
    dosage: null
  }
  state.storeroomList = []
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  :deep(.el-form-item__content) {
    width: 100%;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
  .custom-iframe {
    border: 1px solid #9b9999;
    /* 隐藏原生滚动条 */
    overflow: hidden;
  }
}
</style>
